ChatBottomContainerPrefKey class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

keyboardHeight → const String
Non-directional keyboard height (updates in both portrait and landscape orientations)
keyboardHeightLandscape → const String
Landscape keyboard height
keyboardHeightPortrait → const String
Portrait keyboard height
prefix → const String