ChatBottomPanelContainer<T> class

Inheritance

Constructors

ChatBottomPanelContainer({Key? key, required ChatBottomPanelContainerController<T> controller, required FocusNode inputFocusNode, Widget otherPanelWidget(T? data)?, void onPanelTypeChange(ChatBottomPanelType, T? data)?, Color panelBgColor = Colors.white, double? safeAreaBottom, ChatKeyboardChangeKeyboardPanelHeight? changeKeyboardPanelHeight, ChatBottomCustomPanelContainer<T>? customPanelContainer})
const

Properties

changeKeyboardPanelHeight → ChatKeyboardChangeKeyboardPanelHeight?
The callback to change the height of the keyboard panel.
final
controller → ChatBottomPanelContainerController<T>
The controller of ChatBottomPanelContainer.
final
customPanelContainer → ChatBottomCustomPanelContainer<T>?
The callback to custom panel container.
final
hashCode → int
The hash code for this object.
no setterinherited
inputFocusNode → FocusNode
The focus node of the input box.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPanelTypeChange → void Function(ChatBottomPanelType, T? data)?
The callback when the panel type changes.
final
otherPanelWidget → Widget Function(T? data)?
The widget of the other panel.
final
panelBgColor → Color
The background color of the panel container.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeAreaBottom → double?
The bottom height of the safe area. If it is null, the widget will automatically calculate the bottom height of the safe area.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<ChatBottomPanelContainer>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited