ChatBottomPanelContainerController<T> class

Properties

currentPanelType ↔ ChatBottomPanelType
The current ChatBottomPanelType.
getter/setter pair
data ↔ T?
The data used to associate with user-defined panel types.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isKeyboardHeightChangedByItself → bool
Determine whether the keyboard height changes due to the keyboard's own function. For example, the expansion and closing of the keyboard's own search box.
no setter
keyboardHeight → double
The keyboard height (dynamic height under current orientation). This value may be 0 when the keyboard height has never been recorded under the current orientation.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeAreaBottom → double
The bottom height of the safe area.
no setter

Methods

buildInPanel(ChatBottomPanelType panelType) → Widget?
Build build-in panel.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updatePanelType(ChatBottomPanelType panelType, {T? data, ChatBottomHandleFocus forceHandleFocus = ChatBottomHandleFocus.none}) → void
Update the panel type.

Operators

operator ==(Object other) → bool
The equality operator.
inherited